@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
@@ -161,7 +161,16 @@ _
     },
 };
 sub complete_array_elem {
+    state $code_editdist = do {
+        if (eval { require Text::Levenshtein::XS; 1 }) {
+            \&Text::Levenshtein::XS::distance;
+        } else {
+            \&__editdist;
+        }
+    };
+
     my %args  = @_;
+
     my $array    = $args{array} or die "Please specify array";
     my $word     = $args{word} // "";
     my $ci       = $args{ci} // $Complete::Setting::OPT_CI;
@@ -194,7 +203,7 @@ sub complete_array_elem {
                 my $chopped = substr($eln, 0, $l);
                 my $d;
                 unless (defined $editdists{$chopped}) {
-                    $d = __editdist($wordn, $chopped);
+                    $d = $code_editdist->($wordn, $chopped);
                     $editdists{$chopped} = $d;
                 } else {
                     $d = $editdists{$chopped};
@@ -222,8 +231,6 @@ sub complete_array_elem {
     return $ci ? [sort {lc($a) cmp lc($b)} @words] : [sort @words];
 }
 
-*complete_array = \&complete_array_elem;
-
 $SPEC{complete_hash_key} = {
     v => 1.1,
     summary => 'Complete from hash keys',
@@ -379,7 +386,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.37 of Complete::Util (from Perl distribution Complete-Util), released on 2015-09-17.
+This document describes version 0.38 of Complete::Util (from Perl distribution Complete-Util), released on 2015-09-18.
 
 =head1 DESCRIPTION
 
@@ -513,8 +520,6 @@ Metadata (extra keys) for the hash.
 
 Return value:  (hash)
 
-=for Pod::Coverage ^(complete_array)$
-
 =head1 SEE ALSO
 
 L<Complete>
